==> calamares-settings-solydxk_4.12%2Br13.tar.xz: source/ts/calamares-solydxk_es_419.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es_419" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Gracias por elegir SolydXK&lt;/h3&gt;&lt;br /&gt;Has elegido una distribución de Linux que es:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Segura y estable&lt;/li&gt;&lt;li&gt;Rápida y eficaz &lt;/li&gt;&lt;li&gt;Lista para el escritorio&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Disfruta de esta nueva versión y gracias por elegir SolydXK.&lt;br /&gt;&lt;br /&gt;La instalación tarda entre 15 y 30 minutos, dependiendo de la configuración.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;De pie sobre los hombros de los gigantes&lt;/h3&gt;&lt;br /&gt;SolydXK es una distribución GNU/Linux basada en Debian derivada de Debian y compatible con ella.&lt;br /&gt;&lt;br /&gt;SolydXK utiliza el escritorio ligero Xfce para SolydX o el altamente configurable y asombrosamente atractivo escritorio KDE para SolydK.&lt;br /&gt;&lt;br /&gt;Nuestras innovaciones, el rápido desarrollo de Debian y la enorme selección de paquetes de Debian hacen de SolydXK uno de los sistemas operativos de escritorio más atractivos disponibles para los usuarios domésticos.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Listo para usarse&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird y LibreOffice vienen preinstalados en SolydXK, por lo que puede comenzar inmediatamente con el escritorio e Internet.&lt;br /&gt;&lt;br /&gt;A diferencia de otras distribuciones de Linux, SolydXK también está listo para reproducir música, vídeos de Internet y mucho más.&lt;br /&gt;&lt;br /&gt;Una amplia variedad de software se puede instalar con un clic del ratón.&lt;br /&gt;&lt;br /&gt;SolydXK es compatible con los formatos de archivo más populares, tales como: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, y muchos más.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Las herramientas ofimáticas están listas para su uso tan pronto como instale SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, una potente suite de software de oficina, viene integrada en SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice es muy fácil de aprender y de utilizar.&lt;br /&gt;&lt;br /&gt;Puede utilizarlo para crear cartas, presentaciones y hojas de cálculo, así como diagramas y bases de datos.&lt;br /&gt;&lt;br /&gt;LibreOffice utiliza el formato estándar OpenDocument y funciona con documentos de otras aplicaciones ofimáticas populares, como WordPerfect y Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.&lt;br /&gt;&lt;br /&gt;SolydXK can detect other operating systems and install itself beside them.You can choose which operating system to launch when you start the computer.</source>
        <translation>&lt;h3&gt;Una alternativa a los sistemas operativos convencionales.&lt;/h3&gt;&lt;br /&gt;SolydXK es fácil de usar, potente y configurable.&lt;br /&gt;&lt;br /&gt;SolydXK es seguro y estable. A diferencia de otros sistemas operativos, no es propenso a los virus informáticos ni a los programas espía, no sufre fragmentación del disco y no tiene un registro que requiera una limpieza periódica.&lt;br /&gt;&lt;br /&gt;SolydXK puede detectar otros sistemas operativos e instalarse junto a ellos.Puede elegir qué sistema operativo lanzar al iniciar el equipo.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="143"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Actualizaciones seguras&lt;/h3&gt;&lt;br /&gt;Algunos sistemas operativos hacen que la actualización de su sistema sea más difícil de lo que realmente debe ser. SolydXK cree que las actualizaciones deben ser rápidas y sencillas, y luego salir del paso.&lt;br /&gt;&lt;br /&gt;El Gestor de Actualizaciones se sitúa discretamente en la bandeja del sistema y le permite saber cuándo hay actualizaciones disponibles. No tienes que aplicar las actualizaciones cuando no quieres. El Gestor de Actualizaciones no aparecerá ni le molestará de ninguna manera.&lt;br /&gt;&lt;br /&gt;Todos los archivos actualizados son mantenidos y revisados minuciosamente por desarrolladores y mantenedores de confianza.&lt;br /&gt;&lt;br /&gt;Todos los archivos se almacenan en repositorios seguros especiales para su uso.&lt;br /&gt;&lt;br /&gt;El repositorio de seguridad se sincroniza diariamente.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="165"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Una gran comunidad&lt;/h3&gt;&lt;br /&gt;Los usuarios de SolydXK están encantados de compartir su pasión y entusiasmo y están ansiosos por ayudar. No dude en hacer preguntas en los foros o en involucrarse en la comunidad.&lt;br /&gt;&lt;br /&gt;Envíenos sus comentarios y cuéntenos su experiencia. Escucharemos sus ideas y las utilizaremos para mejorar SolydXK.</translation>
    </message>
</context>
</TS>

==> calamares-settings-solydxk_4.27%2Br13.tar.xz: source/ts/calamares-solydxk_es_419.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es_419" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Gracias por elegir SolydXK&lt;/h3&gt;&lt;br /&gt;Has elegido una distribución de Linux que es:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Segura y estable&lt;/li&gt;&lt;li&gt;Rápida y eficaz &lt;/li&gt;&lt;li&gt;Lista para el escritorio&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Disfruta de esta nueva versión y gracias por elegir SolydXK.&lt;br /&gt;&lt;br /&gt;La instalación tarda entre 15 y 30 minutos, dependiendo de la configuración.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;De pie sobre los hombros de los gigantes&lt;/h3&gt;&lt;br /&gt;SolydXK es una distribución GNU/Linux basada en Debian derivada de Debian y compatible con ella.&lt;br /&gt;&lt;br /&gt;SolydXK utiliza el escritorio ligero Xfce para SolydX o el altamente configurable y asombrosamente atractivo escritorio KDE para SolydK.&lt;br /&gt;&lt;br /&gt;Nuestras innovaciones, el rápido desarrollo de Debian y la enorme selección de paquetes de Debian hacen de SolydXK uno de los sistemas operativos de escritorio más atractivos disponibles para los usuarios domésticos.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Listo para usarse&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird y LibreOffice vienen preinstalados en SolydXK, por lo que puede comenzar inmediatamente con el escritorio e Internet.&lt;br /&gt;&lt;br /&gt;A diferencia de otras distribuciones de Linux, SolydXK también está listo para reproducir música, vídeos de Internet y mucho más.&lt;br /&gt;&lt;br /&gt;Una amplia variedad de software se puede instalar con un clic del ratón.&lt;br /&gt;&lt;br /&gt;SolydXK es compatible con los formatos de archivo más populares, tales como: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, y muchos más.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Las herramientas ofimáticas están listas para su uso tan pronto como instale SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, una potente suite de software de oficina, viene integrada en SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice es muy fácil de aprender y de utilizar.&lt;br /&gt;&lt;br /&gt;Puede utilizarlo para crear cartas, presentaciones y hojas de cálculo, así como diagramas y bases de datos.&lt;br /&gt;&lt;br /&gt;LibreOffice utiliza el formato estándar OpenDocument y funciona con documentos de otras aplicaciones ofimáticas populares, como WordPerfect y Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.</source>
        <translation>&lt;h3&gt;Una alternativa a los sistemas operativos convencionales.&lt;/h3&gt;&lt;br /&gt;SolydXK es fácil de usar, potente y configurable.&lt;br /&gt;&lt;br /&gt;SolydXK es seguro y estable. A diferencia de otros sistemas operativos, no es propenso a los virus informáticos ni a los programas espía, no sufre fragmentación del disco y no tiene un registro que requiera una limpieza periódica.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="142"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Actualizaciones seguras&lt;/h3&gt;&lt;br /&gt;Algunos sistemas operativos hacen que la actualización de su sistema sea más difícil de lo que realmente debe ser. SolydXK cree que las actualizaciones deben ser rápidas y sencillas, y luego salir del paso.&lt;br /&gt;&lt;br /&gt;El Gestor de Actualizaciones se sitúa discretamente en la bandeja del sistema y le permite saber cuándo hay actualizaciones disponibles. No tienes que aplicar las actualizaciones cuando no quieres. El Gestor de Actualizaciones no aparecerá ni le molestará de ninguna manera.&lt;br /&gt;&lt;br /&gt;Todos los archivos actualizados son mantenidos y revisados minuciosamente por desarrolladores y mantenedores de confianza.&lt;br /&gt;&lt;br /&gt;Todos los archivos se almacenan en repositorios seguros especiales para su uso.&lt;br /&gt;&lt;br /&gt;El repositorio de seguridad se sincroniza diariamente.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="164"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Una gran comunidad&lt;/h3&gt;&lt;br /&gt;Los usuarios de SolydXK están encantados de compartir su pasión y entusiasmo y están ansiosos por ayudar. No dude en hacer preguntas en los foros o en involucrarse en la comunidad.&lt;br /&gt;&lt;br /&gt;Envíenos sus comentarios y cuéntenos su experiencia. Escucharemos sus ideas y las utilizaremos para mejorar SolydXK.</translation>
    </message>
</context>
</TS>
